import os
import emod_api.spatialreports.spatial as sr
import matplotlib.pyplot as plt
import numpy as np


def plot_spatial_prev( exp_id, chan="Prevalence", tag="ref" ):
    node_chan_data={}
    node_chan_means = {}
    for sim in os.listdir( os.path.join( exp_id, tag ) ):
        report_path = os.path.join( exp_id, tag, sim, "SpatialReport_" + chan + ".bin" )
        data = sr.SpatialReport( report_path )
        for node_id in data.node_ids:
            chan_data = data[node_id].data
            if node_id not in node_chan_data:
                node_chan_data[ node_id ] = list()
                node_chan_means[ node_id ] = list()
            node_chan_data[ node_id ].append( chan_data )
            node_chan_means[ node_id ] = np.zeros(len(node_chan_data[node_id]))
    for node in node_chan_data.keys():
        node_chan_means[ node ] = np.mean( np.array( node_chan_data[ node ] ), axis=0 )
        plt.plot( node_chan_means[ node ], label=f"node={node}" )
    plt.title( chan )
    plt.legend()
    plt.show()


if __name__ == "__main__": 
    import argparse
    parser = argparse.ArgumentParser(description='Spatial Report Plotting')
    parser.add_argument('-c', '--channel', action='store', default="Prevalence", help='channel(s) to display [Prevalence]' )
    parser.add_argument('-e', '--experiment_id', action='store', default=None, help='experiment id to plot, data assumed to be local' ) 
    args = parser.parse_args()
    if not args.experiment_id:
        with open( "COMPS_ID", "r" ) as fp:
            args.experiment_id = fp.read() 
    if not args.channel:
        args.channel = 'Prevalence'

    # check that folder with name experiment_id exists
    if not os.path.exists( str(args.experiment_id) ):
        raise ValueError( f"Don't see folder for {args.experiment_id}." )

    plot_spatial_prev( str(args.experiment_id), args.channel, tag="ref" )
